Aggregate

Struct Aggregate 

pub struct Aggregate<N, K, L, W, WV, A>
where N: Field, K: Field, L: Field, W: Field, WV: WeightValue, A: Field,
{ pub items: usize, pub names: BTreeMap<N, usize>, pub kinds: BTreeMap<K, usize>, pub labels: BTreeMap<L, usize>, pub weights: BTreeMap<W, WV>, pub annotations: BTreeMap<A, usize>, }
Metadata aggregate values.

Fields

items: usize

Over how many items the aggregate has been taken.

names: BTreeMap<N, usize>

Name occurrence.

kinds: BTreeMap<K, usize>

Kind occurrence.

labels: BTreeMap<L, usize>

Label occurrence.

weights: BTreeMap<W, WV>

Weight sum value.

annotations: BTreeMap<A, usize>

Annotation key occurrence.

Implementations

Source

impl<N, K, L, W, WV, A> Aggregate<N, K, L, W, WV, A>
where N: Field, K: Field, L: Field, W: Field, WV: WeightValue, A: Field,

pub fn builder() -> AggregateBuilder<N, K, L, W, WV, A>

Create an instance of Aggregate using the builder syntax

Source

impl<N, K, L, W, WV, A> Aggregate<N, K, L, W, WV, A>
where N: Field, K: Field, L: Field, W: Field, WV: WeightValue, A: Field,

pub fn new() -> Self

Create a new aggregate instance.

pub fn add<'a, M: ReadMetadata<'a, N, K, L, W, WV, A, AV>, AV: 'a + AnnotationValue>( &'a mut self, item: &'a M, )

Add metadata to the aggregate.

pub fn subtract<'a, M: ReadMetadata<'a, N, K, L, W, WV, A, AV>, AV: 'a + AnnotationValue>( &'a mut self, item: &'a M, )

Subtract metadata from the aggregate.

pub fn extend(&mut self, other: Self)

Add another Aggregate’s values to this.

pub fn aggregate(&self, aggregator: &Aggregator<N, K, L, W, A>) -> f64

Get the sum for all given fields’ values for a given aggregator.

pub fn fraction(&self, aggregator: &Aggregator<N, K, L, W, A>) -> f64

Get a fraction that a field represents with respect to the sum of all fields for a certain aggregator.

pub fn fractions( &self, aggregator: &Aggregator<N, K, L, W, A>, factor: f64, ) -> Vec<f64>

Get all fractions for the given fields with respect to the sum of all fields for a certain aggregator. It can be scaled with a constant factor. Set the factor to 1.0 to ignore scaling.