AggregateBuilder

Struct AggregateBuilder 

pub struct AggregateBuilder<N, K, L, W, WV, A, S: State = Empty>
where N: Field, K: Field, L: Field, W: Field, WV: WeightValue, A: Field,
{ /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<N, K, L, W, WV, A, S: State> AggregateBuilder<N, K, L, W, WV, A, S>
where N: Field, K: Field, L: Field, W: Field, WV: WeightValue, A: Field,

pub fn build(self) -> Aggregate<N, K, L, W, WV, A>
where S: IsComplete,

Finish building and return the requested object

pub fn items( self, value: usize, ) -> AggregateBuilder<N, K, L, W, WV, A, SetItems<S>>
where S::Items: IsUnset,

Optional (Some / Option setters). Default: 0.

Over how many items the aggregate has been taken.

pub fn maybe_items( self, value: Option<usize>, ) -> AggregateBuilder<N, K, L, W, WV, A, SetItems<S>>
where S::Items: IsUnset,

Optional (Some / Option setters). Default: 0.

Over how many items the aggregate has been taken.

pub fn names( self, value: BTreeMap<N, usize>, ) -> AggregateBuilder<N, K, L, W, WV, A, SetNames<S>>
where S::Names: IsUnset,

Optional (Some / Option setters). Default: BTreeMap::new().

Name occurrence.

pub fn maybe_names( self, value: Option<BTreeMap<N, usize>>, ) -> AggregateBuilder<N, K, L, W, WV, A, SetNames<S>>
where S::Names: IsUnset,

Optional (Some / Option setters). Default: BTreeMap::new().

Name occurrence.

pub fn kinds( self, value: BTreeMap<K, usize>, ) -> AggregateBuilder<N, K, L, W, WV, A, SetKinds<S>>
where S::Kinds: IsUnset,

Optional (Some / Option setters). Default: BTreeMap::new().

Kind occurrence.

pub fn maybe_kinds( self, value: Option<BTreeMap<K, usize>>, ) -> AggregateBuilder<N, K, L, W, WV, A, SetKinds<S>>
where S::Kinds: IsUnset,

Optional (Some / Option setters). Default: BTreeMap::new().

Kind occurrence.

pub fn labels( self, value: BTreeMap<L, usize>, ) -> AggregateBuilder<N, K, L, W, WV, A, SetLabels<S>>
where S::Labels: IsUnset,

Optional (Some / Option setters). Default: BTreeMap::new().

Label occurrence.

pub fn maybe_labels( self, value: Option<BTreeMap<L, usize>>, ) -> AggregateBuilder<N, K, L, W, WV, A, SetLabels<S>>
where S::Labels: IsUnset,

Optional (Some / Option setters). Default: BTreeMap::new().

Label occurrence.

pub fn weights( self, value: BTreeMap<W, WV>, ) -> AggregateBuilder<N, K, L, W, WV, A, SetWeights<S>>
where S::Weights: IsUnset,

Optional (Some / Option setters). Default: BTreeMap::new().

Weight sum value.

pub fn maybe_weights( self, value: Option<BTreeMap<W, WV>>, ) -> AggregateBuilder<N, K, L, W, WV, A, SetWeights<S>>
where S::Weights: IsUnset,

Optional (Some / Option setters). Default: BTreeMap::new().

Weight sum value.

pub fn annotations( self, value: BTreeMap<A, usize>, ) -> AggregateBuilder<N, K, L, W, WV, A, SetAnnotations<S>>
where S::Annotations: IsUnset,

Optional (Some / Option setters). Default: BTreeMap::new().

Annotation key occurrence.

pub fn maybe_annotations( self, value: Option<BTreeMap<A, usize>>, ) -> AggregateBuilder<N, K, L, W, WV, A, SetAnnotations<S>>
where S::Annotations: IsUnset,

Optional (Some / Option setters). Default: BTreeMap::new().

Annotation key occurrence.