Metadata

Struct Metadata 

pub struct Metadata<N, K, L, W, WV, A, AV>
where N: Field, K: Field, L: Field, W: Field, WV: WeightValue, A: Field, AV: AnnotationValue,
{ pub id: Uuid, pub name: Option<N>, pub kind: Option<K>, pub labels: BTreeSet<L>, pub weights: BTreeMap<W, WV>, pub annotations: BTreeMap<A, AV>, }
Metadata for any object.

Fields

id: Uuid

Instance identifier. Defaults to a randomly generated UUIDv4.

name: Option<N>

Name associated with this instance.

kind: Option<K>

Kind of object or main category associated with this instance.

labels: BTreeSet<L>

Set of labels associated with this instance.

weights: BTreeMap<W, WV>

Numerical weights associated with this instance.

annotations: BTreeMap<A, AV>

Free-form annotations associated with this instance.

Implementations

Source

impl<N, K, L, W, WV, A, AV> Metadata<N, K, L, W, WV, A, AV>
where N: Field, K: Field, L: Field, W: Field, WV: WeightValue, A: Field, AV: AnnotationValue,

pub fn builder() -> MetadataBuilder<N, K, L, W, WV, A, AV>

Create an instance of Metadata using the builder syntax

Source

impl<N, K, L, W, WV, A, AV> Metadata<N, K, L, W, WV, A, AV>
where N: Field, K: Field, L: Field, W: Field, WV: WeightValue, A: Field, AV: AnnotationValue,

pub fn as_replace_transaction(self) -> Transaction<N, K, L, W, WV, A, AV>

Creates a “replace” transaction from this metadata.

pub fn as_append_transaction(self) -> Transaction<N, K, L, W, WV, A, AV>

Creates an “append” transaction from this metadata.

Source

impl<N, K, L, W, WV, A, AV> Metadata<N, K, L, W, WV, A, AV>
where N: Field, K: Field, L: Field, W: Field, WV: WeightValue, A: Field, AV: AnnotationValue,

pub fn as_ref<'a>(&'a self) -> MetadataRef<'a, N, K, L, W, WV, A, AV>

Create a metadata reference struct from this instance.