MetadataRefBuilder

Struct MetadataRefBuilder 

pub struct MetadataRefBuilder<'a, N, K, L, W, WV, A, AV, S: State = Empty>
where N: Field, K: Field, L: Field, W: Field, WV: WeightValue, A: Field, AV: AnnotationValue,
{ /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<'a, N, K, L, W, WV, A, AV, S: State> MetadataRefBuilder<'a, N, K, L, W, WV, A, AV, S>
where N: Field, K: Field, L: Field, W: Field, WV: WeightValue, A: Field, AV: AnnotationValue,

pub fn build(self) -> MetadataRef<'a, N, K, L, W, WV, A, AV>
where S: IsComplete,

Finish building and return the requested object

pub fn id( self, value: Uuid, ) -> MetadataRefBuilder<'a, N, K, L, W, WV, A, AV, SetId<S>>
where S::Id: IsUnset,

Required.

Instance identifier. Defaults to a randomly generated UUIDv4.

pub fn name( self, value: &'a N, ) -> MetadataRefBuilder<'a, N, K, L, W, WV, A, AV, SetName<S>>
where S::Name: IsUnset,

Optional (Some / Option setters). Name associated with this instance.

pub fn maybe_name( self, value: Option<&'a N>, ) -> MetadataRefBuilder<'a, N, K, L, W, WV, A, AV, SetName<S>>
where S::Name: IsUnset,

Optional (Some / Option setters). Name associated with this instance.

pub fn kind( self, value: &'a K, ) -> MetadataRefBuilder<'a, N, K, L, W, WV, A, AV, SetKind<S>>
where S::Kind: IsUnset,

Optional (Some / Option setters). Kind of object or main category associated with this instance.

pub fn maybe_kind( self, value: Option<&'a K>, ) -> MetadataRefBuilder<'a, N, K, L, W, WV, A, AV, SetKind<S>>
where S::Kind: IsUnset,

Optional (Some / Option setters). Kind of object or main category associated with this instance.

pub fn labels( self, value: BTreeSet<&'a L>, ) -> MetadataRefBuilder<'a, N, K, L, W, WV, A, AV, SetLabels<S>>
where S::Labels: IsUnset,

Optional (Some / Option setters). Default: BTreeSet::new().

Set of labels associated with this instance.

pub fn maybe_labels( self, value: Option<BTreeSet<&'a L>>, ) -> MetadataRefBuilder<'a, N, K, L, W, WV, A, AV, SetLabels<S>>
where S::Labels: IsUnset,

Optional (Some / Option setters). Default: BTreeSet::new().

Set of labels associated with this instance.

pub fn weights( self, value: BTreeMap<&'a W, &'a WV>, ) -> MetadataRefBuilder<'a, N, K, L, W, WV, A, AV, SetWeights<S>>
where S::Weights: IsUnset,

Optional (Some / Option setters). Default: BTreeMap::new().

Numerical weights associated with this instance.

pub fn maybe_weights( self, value: Option<BTreeMap<&'a W, &'a WV>>, ) -> MetadataRefBuilder<'a, N, K, L, W, WV, A, AV, SetWeights<S>>
where S::Weights: IsUnset,

Optional (Some / Option setters). Default: BTreeMap::new().

Numerical weights associated with this instance.

pub fn annotations( self, value: BTreeMap<&'a A, &'a AV>, ) -> MetadataRefBuilder<'a, N, K, L, W, WV, A, AV, SetAnnotations<S>>
where S::Annotations: IsUnset,

Optional (Some / Option setters). Default: BTreeMap::new().

Free-form annotations associated with this instance.

pub fn maybe_annotations( self, value: Option<BTreeMap<&'a A, &'a AV>>, ) -> MetadataRefBuilder<'a, N, K, L, W, WV, A, AV, SetAnnotations<S>>
where S::Annotations: IsUnset,

Optional (Some / Option setters). Default: BTreeMap::new().

Free-form annotations associated with this instance.