TransactionBuilder

Struct TransactionBuilder 

pub struct TransactionBuilder<N, K, L, W, WV, A, AV, S: State = Empty>
where N: Field, K: Field, L: Field, W: Field, WV: WeightValue, A: Field, AV: AnnotationValue,
{ /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<N, K, L, W, WV, A, AV, S: State> TransactionBuilder<N, K, L, W, WV, A, AV, S>
where N: Field, K: Field, L: Field, W: Field, WV: WeightValue, A: Field, AV: AnnotationValue,

pub fn build(self) -> Transaction<N, K, L, W, WV, A, AV>
where S: IsComplete,

Finish building and return the requested object

pub fn mode( self, value: TransactionMode, ) -> TransactionBuilder<N, K, L, W, WV, A, AV, SetMode<S>>
where S::Mode: IsUnset,

Optional (Some / Option setters). Default: <TransactionMode as Default>::default().

Transaction mode.

pub fn maybe_mode( self, value: Option<TransactionMode>, ) -> TransactionBuilder<N, K, L, W, WV, A, AV, SetMode<S>>
where S::Mode: IsUnset,

Optional (Some / Option setters). Default: <TransactionMode as Default>::default().

Transaction mode.

pub fn id( self, value: impl Into<Uuid>, ) -> TransactionBuilder<N, K, L, W, WV, A, AV, SetId<S>>
where S::Id: IsUnset,

Optional (Some / Option setters). Instance identifier.

pub fn maybe_id( self, value: Option<impl Into<Uuid>>, ) -> TransactionBuilder<N, K, L, W, WV, A, AV, SetId<S>>
where S::Id: IsUnset,

Optional (Some / Option setters). Instance identifier.

pub fn name( self, value: impl Into<N>, ) -> TransactionBuilder<N, K, L, W, WV, A, AV, SetName<S>>
where S::Name: IsUnset,

Optional (Some / Option setters). Name associated with this instance.

pub fn maybe_name( self, value: Option<impl Into<N>>, ) -> TransactionBuilder<N, K, L, W, WV, A, AV, SetName<S>>
where S::Name: IsUnset,

Optional (Some / Option setters). Name associated with this instance.

pub fn kind( self, value: impl Into<K>, ) -> TransactionBuilder<N, K, L, W, WV, A, AV, SetKind<S>>
where S::Kind: IsUnset,

Optional (Some / Option setters). Kind of object or main category associated with this instance.

pub fn maybe_kind( self, value: Option<impl Into<K>>, ) -> TransactionBuilder<N, K, L, W, WV, A, AV, SetKind<S>>
where S::Kind: IsUnset,

Optional (Some / Option setters). Kind of object or main category associated with this instance.

pub fn labels( self, value: BTreeSet<L>, ) -> TransactionBuilder<N, K, L, W, WV, A, AV, SetLabels<S>>
where S::Labels: IsUnset,

Optional (Some / Option setters). Set of labels associated with this instance.

pub fn maybe_labels( self, value: Option<BTreeSet<L>>, ) -> TransactionBuilder<N, K, L, W, WV, A, AV, SetLabels<S>>
where S::Labels: IsUnset,

Optional (Some / Option setters). Set of labels associated with this instance.

pub fn weights( self, value: BTreeMap<W, WV>, ) -> TransactionBuilder<N, K, L, W, WV, A, AV, SetWeights<S>>
where S::Weights: IsUnset,

Optional (Some / Option setters). Numerical weights associated with this instance.

pub fn maybe_weights( self, value: Option<BTreeMap<W, WV>>, ) -> TransactionBuilder<N, K, L, W, WV, A, AV, SetWeights<S>>
where S::Weights: IsUnset,

Optional (Some / Option setters). Numerical weights associated with this instance.

pub fn annotations( self, value: BTreeMap<A, AV>, ) -> TransactionBuilder<N, K, L, W, WV, A, AV, SetAnnotations<S>>
where S::Annotations: IsUnset,

Optional (Some / Option setters). Free-form annotations associated with this instance.

pub fn maybe_annotations( self, value: Option<BTreeMap<A, AV>>, ) -> TransactionBuilder<N, K, L, W, WV, A, AV, SetAnnotations<S>>
where S::Annotations: IsUnset,

Optional (Some / Option setters). Free-form annotations associated with this instance.