pub struct Metadata<N, K, L, W, WV, A, AV>{
pub id: Uuid,
pub name: Option<N>,
pub kind: Option<K>,
pub labels: BTreeSet<L>,
pub weights: BTreeMap<W, WV>,
pub annotations: BTreeMap<A, AV>,
}Expand description
Metadata for any object.
Fields
id: UuidInstance identifier. Defaults to a randomly generated UUIDv4.
name: Option<N>Name associated with this instance.
kind: Option<K>Kind of object or main category associated with this instance.
labels: BTreeSet<L>Set of labels associated with this instance.
weights: BTreeMap<W, WV>Numerical weights associated with this instance.
annotations: BTreeMap<A, AV>Free-form annotations associated with this instance.
Implementations
Sourceimpl<N, K, L, W, WV, A, AV> Metadata<N, K, L, W, WV, A, AV>
impl<N, K, L, W, WV, A, AV> Metadata<N, K, L, W, WV, A, AV>
Sourcepub fn builder() -> MetadataBuilder<N, K, L, W, WV, A, AV>
pub fn builder() -> MetadataBuilder<N, K, L, W, WV, A, AV>
Create an instance of Metadata using the builder syntax
Sourceimpl<N, K, L, W, WV, A, AV> Metadata<N, K, L, W, WV, A, AV>
impl<N, K, L, W, WV, A, AV> Metadata<N, K, L, W, WV, A, AV>
Sourcepub fn as_replace_transaction(self) -> Transaction<N, K, L, W, WV, A, AV>
pub fn as_replace_transaction(self) -> Transaction<N, K, L, W, WV, A, AV>
Creates a “replace” transaction from this metadata.
Sourcepub fn as_append_transaction(self) -> Transaction<N, K, L, W, WV, A, AV>
pub fn as_append_transaction(self) -> Transaction<N, K, L, W, WV, A, AV>
Creates an “append” transaction from this metadata.