pub type SimpleMetadataRef<'a> = MetadataRef<'a, String, String, String, String, f64, String, Value>;Expand description
Simplified metadata reference where all fields are encoded as strings, weights as floats and free-form annotations.
Aliased Type
pub struct SimpleMetadataRef<'a> {
pub id: Uuid,
pub name: Option<&'a String>,
pub kind: Option<&'a String>,
pub labels: BTreeSet<&'a String>,
pub weights: BTreeMap<&'a String, &'a f64>,
pub annotations: BTreeMap<&'a String, &'a Value>,
}Fields
id: UuidInstance identifier. Defaults to a randomly generated UUIDv4.
name: Option<&'a String>Name associated with this instance.
kind: Option<&'a String>Kind of object or main category associated with this instance.
labels: BTreeSet<&'a String>Set of labels associated with this instance.
weights: BTreeMap<&'a String, &'a f64>Numerical weights associated with this instance.
annotations: BTreeMap<&'a String, &'a Value>Free-form annotations associated with this instance.