pub struct Transaction<N, K, L, W, WV, A, AV>{
pub mode: TransactionMode,
pub id: Option<Uuid>,
pub name: Option<N>,
pub kind: Option<K>,
pub labels: Option<BTreeSet<L>>,
pub weights: Option<BTreeMap<W, WV>>,
pub annotations: Option<BTreeMap<A, AV>>,
}Expand description
Transaction to apply to a MetadataStore.
Fields
mode: TransactionModeTransaction mode.
id: Option<Uuid>Instance identifier.
name: Option<N>Name associated with this instance.
kind: Option<K>Kind of object or main category associated with this instance.
labels: Option<BTreeSet<L>>Set of labels associated with this instance.
weights: Option<BTreeMap<W, WV>>Numerical weights associated with this instance.
annotations: Option<BTreeMap<A, AV>>Free-form annotations associated with this instance.
Implementations
Sourceimpl<N, K, L, W, WV, A, AV> Transaction<N, K, L, W, WV, A, AV>
impl<N, K, L, W, WV, A, AV> Transaction<N, K, L, W, WV, A, AV>
Sourcepub fn builder() -> TransactionBuilder<N, K, L, W, WV, A, AV>
pub fn builder() -> TransactionBuilder<N, K, L, W, WV, A, AV>
Create an instance of Transaction using the builder syntax
Sourceimpl<N, K, L, W, WV, A, AV> Transaction<N, K, L, W, WV, A, AV>
impl<N, K, L, W, WV, A, AV> Transaction<N, K, L, W, WV, A, AV>